#!/usr/bin/python

#This program is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License version 3 as
#published by the Free Software Foundation;

#This program is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.

#You should have received a copy of the GNU General Public License
#along with this program; if not, write to the Free Software
#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#Author: Marco Guastella alias Vasta
#Web page:<www.ragnu.it>
#Email: <vasta@ragnu.it>
#Date last Update : 22/10/2019

#use setup and pysetup  as explained in installer software
#import vmpbuild as build

import vmpconfig as config
import vmppybuild as pybuild
##dor javascript installer
#import vmpjbuild  as jbuild

##Module name
name="base"

pysetup=pybuild.pysetup()
pysetup.dependencies=['vmp','vmp_plugin']

#jsetup=jbuild.jsetup()
#jsetup.dirmain=config.gmodule_jsmain(name)
#jsetup.index=[("index","title page","roottag",["file"],["file"])...(name,title page,root tag,[css file list] [javascript file list]]
#jsetup.dependencies=["vmp"]

def description():
    return "description module"
    
def install():
    pybuild.pybuild(pysetup)
    #jbuild.jbuild(jsetup)

def uninstall():
    pybuild.pyclear(pysetup)
    #jbuild.jclear(jsetup) 

